@@ -52,19 +52,20 @@ App::MFILE - MFILE shared modules
 
 =head1 VERSION
 
-Version 0.172
+Version 0.173
 
 =cut
 
-our $VERSION = '0.172';
+our $VERSION = '0.173';
 
 
 
 
 =head1 DESCRIPTION
 
-This distro consists of general, reusable modules. Currently the modules
-are used mainly by L<App::MFILE::WWW> and other similar frontends.
+This distro consists of general, reusable modules. Currently, there is only
+one module, L<App::MFILE::HTTP>, which is used by L<App::MFILE::WWW>,
+L<App::Dochazka::WWW>, and L<App::Dochazka::CLI>.
 
 =cut
 
